# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.8.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NameIdPolicyEnum(str, Enum):
    """
    NameIdPolicyEnum
    """

    """
    allowed enum values
    """
    URN_COLON_OASIS_COLON_NAMES_COLON_TC_COLON_SAML_COLON_1_DOT_1_COLON_NAMEID_MINUS_FORMAT_COLON_EMAIL_ADDRESS = 'urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'
    URN_COLON_OASIS_COLON_NAMES_COLON_TC_COLON_SAML_COLON_2_DOT_0_COLON_NAMEID_MINUS_FORMAT_COLON_PERSISTENT = 'urn:oasis:names:tc:SAML:2.0:nameid-format:persistent'
    URN_COLON_OASIS_COLON_NAMES_COLON_TC_COLON_SAML_COLON_1_DOT_1_COLON_NAMEID_MINUS_FORMAT_COLON_X509_SUBJECT_NAME = 'urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName'
    URN_COLON_OASIS_COLON_NAMES_COLON_TC_COLON_SAML_COLON_2_DOT_0_COLON_NAMEID_MINUS_FORMAT_COLON_WINDOWS_DOMAIN_QUALIFIED_NAME = 'urn:oasis:names:tc:SAML:2.0:nameid-format:WindowsDomainQualifiedName'
    URN_COLON_OASIS_COLON_NAMES_COLON_TC_COLON_SAML_COLON_2_DOT_0_COLON_NAMEID_MINUS_FORMAT_COLON_TRANSIENT = 'urn:oasis:names:tc:SAML:2.0:nameid-format:transient'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NameIdPolicyEnum from a JSON string"""
        return cls(json.loads(json_str))


